import { useCssVar } from '@vueuse/core';

const BASE_FONT_SIZE = 16;

/** @description 节点与文字间距 */
const NODE_TEXT_SPACE = 4;
const circle = {
	r: 0,
	magnet: false,
	// stroke: '#5F95FF',
	// strokeWidth: 1,
	// fill: '#fff',
	style: {
		visibility: 'hidden',
	},
};

const directionPorts = (id) => {
	const topId = `${id}-t`;
	const bottomId = `${id}-b`;
	const leftId = `${id}-l`;
	const rightId = `${id}-r`;

	return {
		groups: {
			top: {
				position: 'top',
				attrs: { circle },
			},

			bottom: {
				position: 'bottom',
				attrs: { circle },
			},
			left: {
				position: 'left',
				attrs: { circle },
			},

			right: {
				position: 'right',
				attrs: { circle },
			},
		},
		items: [
			{
				id: topId,
				group: 'top',
			},

			{
				id: bottomId,
				group: 'bottom',
			},
			{
				id: leftId,
				group: 'left',
			},

			{
				id: rightId,
				group: 'right',
			},
		],
	};
};

export const rectShape = (id, name) => ({
	shape:'rect',
	width: 80,
	height: 42,
	attrs: {
		body: {
			stroke: useCssVar('--el-color-success').value,
			strokeWidth: 1,
			fill: useCssVar('--el-color-success-light-7').value,
		},
		text: {
			text: name,
			fontSize: BASE_FONT_SIZE,
			fill: '#080808',
			class: 'name',

			refY: '0',
			refY2: -NODE_TEXT_SPACE,
			yAlign: 'bottom',
		},
	},
	markup: [
		{
			tagName: 'rect',
			selector: 'body',
		},
		{
			tagName: 'text',
			selector: 'text',
		},
	],
	ports: { ...directionPorts(id) },
});




export const ellipseShape = (id, name) => ({
	shape:'rect',
	width: 80,
	height: 42,
	attrs: {
		body: {
			stroke: useCssVar('--el-color-warning').value,
			strokeWidth: 1,
			fill: useCssVar('--el-color-warning-light-7').value,
		},
		text: {
			text: name,
			fontSize: BASE_FONT_SIZE,
			fill: '#080808',
			class: 'name',

			refX: '100%',
			refX2: NODE_TEXT_SPACE,
			xAlign: 'left',
		},
	},
	markup: [
		{
			tagName: 'rect',
			selector: 'body',
		},
		{
			tagName: 'text',
			selector: 'text',
		},
	],
	ports: { ...directionPorts(id) },
});
export const verticalRectShape = (id, name) => ({
	width: 30,
	height: 100,
	attrs: {
		body: {
			stroke: '#5F95FF',
			strokeWidth: 1,
			fill: '#ffffff',
		},
		text: {
			text: name,
			fontSize: BASE_FONT_SIZE,
			fill: '#080808',
			writingMode: 'tb-rl',
			class: 'name',
		},
	},
	markup: [
		{
			tagName: 'rect',
			selector: 'body',
		},
		{
			tagName: 'text',
			selector: 'text',
		},
	],
	ports: { ...directionPorts(id) },
});

export const circleShape = (id, name) => {
	return {
		shape: 'circle',
		ports: { ...directionPorts(id) },
		width: 65,
		height: 65,
		attrs: {
			body: {
				strokeWidth: 2,
				stroke: useCssVar('--el-color-primary').value,
				fill: useCssVar('--el-color-primary-light-7').value,
			},
			text: {
				text: name,
				fontSize: BASE_FONT_SIZE,
				fill: '#080808',
				// writingMode: 'tb-rl',
				class: 'name',
				// refX: '100%',
				// refX2: NODE_TEXT_SPACE,
				// refY: '50%',
				// xAlign: 'left',


				refX: '50%',
				refY: '100%',
				refY2: NODE_TEXT_SPACE,
				yAlign: 'top',
			},
		},
	};
};
export const edgeShape = {
	attrs: {
		line: {
			strokeWidth: 2, //线宽
			stroke: useCssVar('--el-color-info-light-3').value, //线色
			strokeDasharray: 0, //虚线间隔
			style: {
				animation: 'ant-line 0s infinite linear', //动画  虚线时有效
			},
			sourceMarker: null, //起始点 标记
			// targetMarker: {
			// 	//结束点 标记
			// 	name: 'block', //内置箭头
			// 	width: 12,
			// 	height: 8,
			// },
			targetMarker: null,
		},
	},
};
